@@ -15,22 +15,46 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """Connect to Asana."""
-import sys
-from typing import Any, Dict, Optional
+from __future__ import annotations
 
-from asana import Client
-from asana.error import NotFoundError
+from functools import cached_property, wraps
+from typing import Any
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
+from asana import Client  # type: ignore[attr-defined]
+from asana.error import NotFoundError  # type: ignore[attr-defined]
 
 from airflow.hooks.base import BaseHook
 
 
+def _ensure_prefixes(conn_type):
+    """
+    Remove when provider min airflow version >= 2.5.0 since this is handled by
+    provider manager from that version.
+    """
+
+    def dec(func):
+        @wraps(func)
+        def inner():
+            field_behaviors = func()
+            conn_attrs = {"host", "schema", "login", "password", "port", "extra"}
+
+            def _ensure_prefix(field):
+                if field not in conn_attrs and not field.startswith("extra__"):
+                    return f"extra__{conn_type}__{field}"
+                else:
+                    return field
+
+            if "placeholders" in field_behaviors:
+                placeholders = field_behaviors["placeholders"]
+                field_behaviors["placeholders"] = {_ensure_prefix(k): v for k, v in placeholders.items()}
+            return field_behaviors
+
+        return inner
+
+    return dec
+
+
 class AsanaHook(BaseHook):
     """Wrapper around Asana Python client library."""
 
@@ -43,40 +67,54 @@ class AsanaHook(BaseHook):
         super().__init__(*args, **kwargs)
         self.connection = self.get_connection(conn_id)
         extras = self.connection.extra_dejson
-        self.workspace = extras.get("extra__asana__workspace") or None
-        self.project = extras.get("extra__asana__project") or None
+        self.workspace = self._get_field(extras, "workspace") or None
+        self.project = self._get_field(extras, "project") or None
+
+    def _get_field(self, extras: dict, field_name: str):
+        """Get field from extra, first checking short name, then for backcompat we check for prefixed name."""
+        backcompat_prefix = "extra__asana__"
+        if field_name.startswith("extra__"):
+            raise ValueError(
+                f"Got prefixed name {field_name}; please remove the '{backcompat_prefix}' prefix "
+                "when using this method."
+            )
+        if field_name in extras:
+            return extras[field_name] or None
+        prefixed_name = f"{backcompat_prefix}{field_name}"
+        return extras.get(prefixed_name) or None
 
     def get_conn(self) -> Client:
         return self.client
 
     @staticmethod
-    def get_connection_form_widgets() -> Dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+    def get_connection_form_widgets() -> dict[str, Any]:
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import StringField
 
         return {
-            "extra__asana__workspace": StringField(lazy_gettext("Workspace"), widget=BS3TextFieldWidget()),
-            "extra__asana__project": StringField(lazy_gettext("Project"), widget=BS3TextFieldWidget()),
+            "workspace": StringField(lazy_gettext("Workspace"), widget=BS3TextFieldWidget()),
+            "project": StringField(lazy_gettext("Project"), widget=BS3TextFieldWidget()),
         }
 
     @staticmethod
-    def get_ui_field_behaviour() -> Dict[str, Any]:
-        """Returns custom field behaviour"""
+    @_ensure_prefixes(conn_type="asana")
+    def get_ui_field_behaviour() -> dict[str, Any]:
+        """Returns custom field behaviour."""
         return {
             "hidden_fields": ["port", "host", "login", "schema"],
             "relabeling": {},
             "placeholders": {
                 "password": "Asana personal access token",
-                "extra__asana__workspace": "Asana workspace gid",
-                "extra__asana__project": "Asana project gid",
+                "workspace": "Asana workspace gid",
+                "project": "Asana project gid",
             },
         }
 
     @cached_property
     def client(self) -> Client:
-        """Instantiates python-asana Client"""
+        """Instantiates python-asana Client."""
         if not self.connection.password:
             raise ValueError(
                 "Asana connection password must contain a personal access token: "
@@ -85,7 +123,7 @@ class AsanaHook(BaseHook):
 
         return Client.access_token(self.connection.password)
 
-    def create_task(self, task_name: str, params: Optional[dict]) -> dict:
+    def create_task(self, task_name: str, params: dict | None) -> dict:
         """
         Creates an Asana task.
 
@@ -99,7 +137,7 @@ class AsanaHook(BaseHook):
         response = self.client.tasks.create(params=merged_params)
         return response
 
-    def _merge_create_task_parameters(self, task_name: str, task_params: Optional[dict]) -> dict:
+    def _merge_create_task_parameters(self, task_name: str, task_params: dict | None) -> dict:
         """
         Merge create_task parameters with default params from the connection.
 
@@ -107,7 +145,7 @@ class AsanaHook(BaseHook):
         :param task_params: Other task parameters which should override defaults from the connection
         :return: A dict of merged parameters to use in the new task
         """
-        merged_params: Dict[str, Any] = {"name": task_name}
+        merged_params: dict[str, Any] = {"name": task_name}
         if self.project:
             merged_params["projects"] = [self.project]
         # Only use default workspace if user did not provide a project id
@@ -145,7 +183,7 @@ class AsanaHook(BaseHook):
             self.log.info("Asana task %s not found for deletion.", task_id)
             return {}
 
-    def find_task(self, params: Optional[dict]) -> list:
+    def find_task(self, params: dict | None) -> list:
         """
         Retrieves a list of Asana tasks that match search parameters.
 
@@ -158,7 +196,7 @@ class AsanaHook(BaseHook):
         response = self.client.tasks.find_all(params=merged_params)
         return list(response)
 
-    def _merge_find_task_parameters(self, search_parameters: Optional[dict]) -> dict:
+    def _merge_find_task_parameters(self, search_parameters: dict | None) -> dict:
         """
         Merge find_task parameters with default params from the connection.
 
@@ -223,7 +261,7 @@ class AsanaHook(BaseHook):
     @staticmethod
     def _validate_create_project_parameters(params: dict) -> None:
         """
-        Check that user provided the minimum required parameters for project creation
+        Check that user provided the minimum required parameters for project creation.
 
         :param params: Attributes that the new project should have
         :return: None; raises a ValueError if `params` does not contain the minimum required attributes.
